//------------------------------------------------------------------------------
//  filename:   ltadll.h
//  Description.
//     lta.dll .
//  
//------------------------------------------------------------------------------

#ifndef ltadll_h__
#define ltadll_h__

#include <stdint.h>

//------------------------------------------------------------------------------
// T Y P E S  and  D E F I N I T I O N S
//------------------------------------------------------------------------------

//   .    
//   .     . 
// 
typedef uint32_t Lta_handle;


//    .
// 
typedef uint32_t Lta_error;

//    :
//
enum Lta_error_code
{
    lta_no_error = 0U,              //  .
    lta_invalid_handle = 1U,        //    (,   ).
    lta_win32api_error = 2U,        //   API (ReadFile, WriteFile, ...)   .
    lta_invalid_param = 3U,         // ,   ,   .
    lta_timeout_error = 4U,         //  .
    lta_recv_overflow_error = 5U,   //    ,    .
                                    //   .
    lta_format_error = 6U,          //       .
};


//      /  
// .    LtaEnumerate().
// 
typedef void (__stdcall *Lta_plug_event)(Lta_handle);
typedef void (__stdcall *Lta_unplug_event)(Lta_handle);
typedef bool (__stdcall *Lta_enumerate_event)(Lta_handle);

//         
// / .
//     .  
//     .
// 
//       !
// 
typedef void (__stdcall *Lta_data_event)(Lta_handle, const void*, uint16_t);
typedef void (__stdcall *Lta_device_change_event)();


//------------------------------------------------------------------------------
// G L O B A L F U N C T I O N S
//------------------------------------------------------------------------------

//  .    .  
//    ( false),    .dll
//  true   , false   .
// 
extern "C" bool __stdcall LtaInit();


//     .   
//   .
// 
extern "C" void __stdcall LtaDeinit();


//  true,     (  
// ).
// 
extern "C" bool __stdcall LtaIsHandleValid(Lta_handle h);


//     .
//      h = nullptr.
//
extern "C" void __stdcall LtaSetPlugHandler(Lta_plug_event h);
extern "C" void __stdcall LtaSetUnplugHandler(Lta_unplug_event h);
extern "C" void __stdcall LtaSetEnumerateHandler(Lta_enumerate_event h);
extern "C" void __stdcall LtaSetDeviceChangeHandler(Lta_device_change_event h);
extern "C" void __stdcall LtaSetDataHandler(Lta_handle dev, Lta_data_event h);


//   .     
// Lta_unplug_event     , Lta_plug_event  
//   Lta_enumerate_event   .   Enumerate
//   false,   Lta_enumerate_event   
//   .
// 
extern "C" void __stdcall LtaEnumerate();


//       .
//     ,   0.
// 
extern "C" Lta_handle __stdcall LtaCheckoutBySerialNumber(const wchar_t* serial);


//         buf,
//      const uint8_t*.
// 
extern "C" Lta_error __stdcall LtaSend(Lta_handle h, const void* buf, uint32_t size);


//    hid      
//  .
// h -  ;
// buf -   (    uint8_t*);
// size -   ;
// tm -    .   2000.
//  *recv     
//    .
//
//    lta_timeout_error  lta_recv_overflow_error,
//        ,  
//  .      *recv.
//
extern "C" Lta_error __stdcall LtaReceive(Lta_handle h, void* buf, uint32_t size, uint32_t tm, uint32_t* recv);


//      size     .
// 
extern "C" Lta_error __stdcall LtaGetSerialNumber(Lta_handle h, wchar_t* buf, uint32_t size);


//         .
// 
extern "C" Lta_error __stdcall LtaFlushInputQueue(Lta_handle h);


//------------------------------------------------------------------------------
// G L O B A L V A R I A B L E S
//------------------------------------------------------------------------------


#endif // ltadll_h__